=================
nicfit.py README
=================

|Build Status| |License| |PyPI| |Python versions| |Coverage| |Status|

Basic building blocks for building Python applications.


Features
--------

* Common appplication skeletons (including async) providing common argument
  parsing add-ons and utilities, error handling boiler-plate, and application
  life-cycle hooks. Including intregrated `cookiecutter` that
  suuports updating to future versions with auto-merging.
* Simple command API based on `argparse` and sub-parsers.
* Integrated configuation file (based on configparser) utitiles.
* Logging extras (e.g. verbose level) and command line configuration.
* Free software: MIT license


.. |Build Status| image:: https://travis-ci.org/nicfit/nicfit.py.svg?branch=master
   :target: https://travis-ci.org/nicfit/nicfit.py
   :alt: Build Status
.. |PyPI| image:: https://img.shields.io/pypi/v/nicfit.py.svg
   :target: https://pypi.python.org/pypi/nicfit.py/
   :alt: Latest Version
.. |Python versions| image:: https://img.shields.io/pypi/pyversions/nicfit.py.svg
   :target: https://pypi.python.org/pypi/nicfit.py/
   :alt: Supported Python versions
.. |License| image:: https://img.shields.io/pypi/l/nicfit.py.svg
   :target: https://pypi.python.org/pypi/nicfit.py/
   :alt: License
.. |Status| image:: https://img.shields.io/pypi/status/nicfit.py.svg
   :target: https://pypi.python.org/pypi/nicfit.py/
   :alt: Project Status
.. |Coverage| image:: https://coveralls.io/repos/nicfit/nicfit.py/badge.svg
   :target: https://coveralls.io/r/nicfit/nicfit.py
   :alt: Coverage Status
